==> docstrinator-0.01.tar.gz: docstrinator-0.01/setup.py <==
from distutils.core import setup

setup(
  name = 'docstrinator',         # How you named your package folder (MyLib)
  packages = ['docstrinator'],   # Chose the same as "name"
  version = '0.01',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Decorator to generate docstrings for functions',   # Give a short description about your library
  author = 'Andrey',                   # Type in your name
  #author_email = 'your.email@domain.com',      # Type in your E-Mail
  url = 'https://github.com/unique-andy/docstrinator',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/unique-andy/docstrinator/archive/v_01.tar.gz',    # I explain this later on
  keywords = ['docs', 'python', 'docstrings'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'inspect',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)

==> docstrinator-0.02.tar.gz: docstrinator-0.02/setup.py <==
from distutils.core import setup

setup(
  name = 'docstrinator',         # How you named your package folder (MyLib)
  packages = ['docstrinator'],   # Chose the same as "name"
  version = '0.02',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'Decorator to generate docstrings for functions',   # Give a short description about your library
  author = 'Andrey',                   # Type in your name
  #author_email = 'your.email@domain.com',      # Type in your E-Mail
  url = 'https://github.com/unique-andy/docstrinator',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/unique-andy/docstrinator/archive/v_02.tar.gz',    # I explain this later on
  keywords = ['docs', 'python', 'docstrings'],   # Keywords that define your package best
  # install_requires=[            # I get to this in a second
  #         'inspect',
  #     ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.8',
  ],
)
